@@ -4,8 +4,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef CALENDARSUPPORT_CELLITEM_H
-#define CALENDARSUPPORT_CELLITEM_H
+#pragma once
 
 #include "calendarsupport_export.h"
 #include <QList>
@@ -15,23 +14,19 @@ namespace CalendarSupport
 class CALENDARSUPPORT_EXPORT CellItem
 {
 public:
-    CellItem()
-    {
-    }
+    CellItem() = default;
 
-    virtual ~CellItem()
-    {
-    }
+    virtual ~CellItem() = default;
 
     void setSubCells(int v);
-    Q_REQUIRED_RESULT int subCells() const;
+    [[nodiscard]] int subCells() const;
 
     void setSubCell(int v);
-    Q_REQUIRED_RESULT int subCell() const;
+    [[nodiscard]] int subCell() const;
 
     virtual bool overlaps(CellItem *other) const = 0;
 
-    Q_REQUIRED_RESULT virtual QString label() const;
+    [[nodiscard]] virtual QString label() const;
 
     /**
       Place item @p placeItem into stripe containing items @p cells in a
@@ -48,5 +43,3 @@ private:
     int mSubCell = -1;
 };
 }
-
-#endif
