@@ -9,6 +9,7 @@
 #pragma once
 
 #include "calendarsupport_export.h"
+
 #include "calprintpluginbase.h"
 
 #include "ui_calprintdayconfig_base.h"
@@ -18,7 +19,7 @@
 #include "ui_calprintweekconfig_base.h"
 
 #include <KLocalizedString>
-
+using namespace Qt::Literals::StringLiterals;
 namespace CalendarSupport
 {
 class CALENDARSUPPORT_EXPORT CalPrintIncidence : public CalPrintPluginBase
@@ -28,7 +29,7 @@ public:
     ~CalPrintIncidence() override;
     [[nodiscard]] QString groupName() const override
     {
-        return QStringLiteral("Print incidence");
+        return u"Print incidence"_s;
     }
 
     [[nodiscard]] QString description() const override
@@ -130,7 +131,7 @@ public:
     ~CalPrintDay() override;
     [[nodiscard]] QString groupName() const override
     {
-        return QStringLiteral("Print day");
+        return u"Print day"_s;
     }
 
     [[nodiscard]] QString description() const override
@@ -163,7 +164,11 @@ public:
     void setDateRange(const QDate &from, const QDate &to) override;
 
 protected:
-    enum eDayPrintType { Filofax = 0, Timetable, SingleTimetable } mDayPrintType;
+    enum eDayPrintType {
+        Filofax = 0,
+        Timetable,
+        SingleTimetable
+    } mDayPrintType;
 
     /**
       Draw the (filofax) table for a bunch of days, using drawDayBox.
@@ -183,27 +188,27 @@ public:
     CalPrintWeek();
     ~CalPrintWeek() override;
 
-    QString groupName() const override
+    [[nodiscard]] QString groupName() const override
     {
-        return QStringLiteral("Print week");
+        return u"Print week"_s;
     }
 
-    QString description() const override
+    [[nodiscard]] QString description() const override
     {
         return i18n("Print &week");
     }
 
-    QString info() const override
+    [[nodiscard]] QString info() const override
     {
         return i18n("Prints all events of one week on one page");
     }
 
-    int sortID() const override
+    [[nodiscard]] int sortID() const override
     {
         return CalPrinterBase::Week;
     }
 
-    bool enabled() const override
+    [[nodiscard]] bool enabled() const override
     {
         return true;
     }
@@ -223,7 +228,11 @@ public:
     void setDateRange(const QDate &from, const QDate &to) override;
 
 protected:
-    enum eWeekPrintType { Filofax = 0, Timetable, SplitWeek } mWeekPrintType;
+    enum eWeekPrintType {
+        Filofax = 0,
+        Timetable,
+        SplitWeek
+    } mWeekPrintType;
 
     /**
       Draw the week (filofax) table of the week containing the date qd. The first
@@ -247,7 +256,7 @@ public:
     ~CalPrintMonth() override;
     QString groupName() const override
     {
-        return QStringLiteral("Print month");
+        return u"Print month"_s;
     }
 
     QString description() const override
@@ -302,7 +311,7 @@ public:
 
     QString groupName() const override
     {
-        return QStringLiteral("Print to-dos");
+        return u"Print to-dos"_s;
     }
 
     QString description() const override
@@ -337,7 +346,11 @@ public:
 protected:
     QString mPageTitle;
 
-    enum eTodoPrintType { TodosAll = 0, TodosUnfinished, TodosDueRange } mTodoPrintType;
+    enum eTodoPrintType {
+        TodosAll = 0,
+        TodosUnfinished,
+        TodosDueRange
+    } mTodoPrintType;
 
     enum eTodoSortField {
         TodoFieldSummary = 0,
@@ -349,7 +362,11 @@ protected:
         TodoFieldUnset
     } mTodoSortField;
 
-    enum eTodoSortDirection { TodoDirectionAscending = 0, TodoDirectionDescending, TodoDirectionUnset } mTodoSortDirection;
+    enum eTodoSortDirection {
+        TodoDirectionAscending = 0,
+        TodoDirectionDescending,
+        TodoDirectionUnset
+    } mTodoSortDirection;
 
     bool mIncludeDescription;
     bool mIncludePriority;
